@@ -913,6 +913,10 @@ opplasting mislyktes</translation>
         <source>File save failed</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Index progress request error %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserSearchModel</name>
@@ -1086,13 +1090,6 @@ opplasting mislyktes</translation>
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>FinderSyncHost</name>
-    <message>
-        <source>Failed to get link</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>GetFileTask</name>
     <message>
@@ -1480,11 +1477,6 @@ Do you like to download your default library?</source>
 </context>
 <context>
     <name>MessagePoller</name>
-    <message>
-        <source>&quot;%1&quot; is unsynced. 
-Reason: Deleted on server</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&quot;%1&quot; is synchronized</source>
         <translation type="unfinished"/>
@@ -1493,10 +1485,6 @@ Reason: Deleted on server</source>
         <source>Files uploaded to &quot;%1&quot;</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>File %1 conflict</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to sync file %1
 File is locked by other application. This file will be updated when you close the application.</source>
@@ -1532,13 +1520,23 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>&quot;%1&quot; failed to sync. 
-Access denied to service</source>
+        <source>No permission to sync folder %1.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>&quot;%1&quot; failed to sync.
-The library owner&apos;s storage space is used up.</source>
+        <source>Updates in read-only library %1 will not be uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Concurrent updates to file. File %1 is saved as conflict file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Folder %1 is moved to seafile-recycle-bin folder since it contains not-yet uploaded files.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Folder for library %1 is removed or moved. The library is unsynced.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1675,54 +1673,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>unknown</source>
         <translation>ukjent</translation>
     </message>
-    <message>
-        <source>Server has been removed</source>
-        <translation>Serveren er fjernet</translation>
-    </message>
-    <message>
-        <source>You have not logged in to the server</source>
-        <translation>Du har ikke logget på serveren</translation>
-    </message>
-    <message>
-        <source>You do not have permission to access this library</source>
-        <translation>Du har ikke tillatelse til å åpne dette biblioteket</translation>
-    </message>
-    <message>
-        <source>The storage space of the library owner has been used up</source>
-        <translation>Bibliotekets eier har bruk opp all sin tildelte lagringsplass</translation>
-    </message>
-    <message>
-        <source>Remote service is not available</source>
-        <translation>Tjenesten er ikke tilgjengelig</translation>
-    </message>
-    <message>
-        <source>Access denied to service</source>
-        <translation>Ingen tilgang til tjenesten</translation>
-    </message>
-    <message>
-        <source>Internal data corrupted</source>
-        <translation>Interne data er korrupte</translation>
-    </message>
-    <message>
-        <source>Failed to start upload</source>
-        <translation>Kunne ikke starte opplastingen</translation>
-    </message>
-    <message>
-        <source>Failed to start download</source>
-        <translation>Kunne ikke starte nedlastingen</translation>
-    </message>
-    <message>
-        <source>Library is damaged on server</source>
-        <translation>Biblioteket er skadd på serveren</translation>
-    </message>
-    <message>
-        <source>Conflict in merge</source>
-        <translation>Konflikt i samordningen</translation>
-    </message>
-    <message>
-        <source>Server version is too old</source>
-        <translation>Serverversjonen er for gammel</translation>
-    </message>
     <message>
         <source>Unknown error</source>
         <translation>Ukjent feil</translation>
@@ -1763,10 +1713,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>Server error</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Bad request</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation type="unfinished"/>
@@ -1791,58 +1737,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>The storage quota has been used up</source>
         <translation>Tildelt lagringsplass er oppbrukt</translation>
     </message>
-    <message>
-        <source>Internal server error</source>
-        <translation>Intern serverfeil</translation>
-    </message>
-    <message>
-        <source>Your %1 client is too old</source>
-        <translation>Din %1 klient er for gammel</translation>
-    </message>
-    <message>
-        <source>Failed to sync this library</source>
-        <translation>Kunne ikke synkronisere dette biblioteket</translation>
-    </message>
-    <message>
-        <source>Files are locked by other application</source>
-        <translation>Filene er låste av en annen applikasjon</translation>
-    </message>
-    <message>
-        <source>Library is deleted on server</source>
-        <translation>Biblioteket er slettet på serveren</translation>
-    </message>
-    <message>
-        <source>Error when accessing the local folder</source>
-        <translation>Feil oppsto ved forsøk på å åpne den lokale mappen</translation>
-    </message>
     <message>
         <source>initializing...</source>
         <translation>Initialiserer....</translation>
     </message>
-    <message>
-        <source>Failed to index local files</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to check server information</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to create local files</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to merge local file changes</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Incorrect password. Please download again</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Internal error</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>connecting server...</source>
         <translation>kobler til server...</translation>
@@ -2143,18 +2041,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>%1 Client is already running</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occurred in upload</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Error occurred in download</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Permission denied on server. Please try to resync the library</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Internal data corrupt on the client. Please try to resync the library</source>
         <translation type="unfinished"/>
@@ -2164,11 +2050,103 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Do not have permission to sync the library</source>
+        <source>No permission to sync this folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>No permission to sync this folder</source>
+        <source>Removed all items from trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Removed items older than days %1 from trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Published draft</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created draft</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Renamed file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted draft</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restored file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Moved file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Updated file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Renamed folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restored folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Moved folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Renamed library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restored library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created or updated a file in a non-writable library or folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission denied on server</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Concurrent updates to file. File is saved as conflict file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>A folder that may contain not-yet-uploaded files is moved to seafile-recycle-bin folder.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -2209,10 +2187,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>RepoName</source>
         <translation>Kodelagernavn</translation>
     </message>
-    <message>
-        <source>Description:</source>
-        <translation>Beskrivelse:</translation>
-    </message>
     <message>
         <source>TextLabel</source>
         <translation>Tekstetikett</translation>
@@ -2563,6 +2537,29 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SeafileExtensionHandler</name>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to lock file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to unlock file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; is locked by %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to get lock information for file &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>SeafileLinkDialog</name>
     <message>
@@ -2581,6 +2578,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>%1 Internal Link:</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Desktop Access Link:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileRpcClient</name>
@@ -2683,6 +2684,22 @@ The library owner&apos;s storage space is used up.</source>
         <source>Please login first</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Repair explorer extension</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Successfully fixed sync status icons for Explorer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Faild to fix sync status icons for Explorer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>have some sync error</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SearchResultListView</name>
