@@ -1085,13 +1085,6 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>FinderSyncHost</name>
-    <message>
-        <source>Failed to get link</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>GetFileTask</name>
     <message>
@@ -1476,11 +1469,6 @@ Do you like to download your default library?</source>
 </context>
 <context>
     <name>MessagePoller</name>
-    <message>
-        <source>&quot;%1&quot; is unsynced. 
-Reason: Deleted on server</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&quot;%1&quot; is synchronized</source>
         <translation type="unfinished"/>
@@ -1489,10 +1477,6 @@ Reason: Deleted on server</source>
         <source>Files uploaded to &quot;%1&quot;</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>File %1 conflict</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to sync file %1
 File is locked by other application. This file will be updated when you close the application.</source>
@@ -1527,22 +1511,24 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Update to file %1 is denied by folder permission setting.</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>&quot;%1&quot; failed to sync. 
-Access denied to service</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&quot;%1&quot; failed to sync.
-The library owner&apos;s storage space is used up.</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>No permission to sync folder %1.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Updates in read-only library will not be uploaded.</source>
+        <source>Updates in read-only library %1 will not be uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Concurrent updates to file. File %1 is saved as conflict file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Folder %1 is moved to seafile-recycle-bin folder since it contains not-yet uploaded files.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Folder for library %1 is removed or moved. The library is unsynced.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1679,54 +1665,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>unknown</source>
         <translation>desconhecido</translation>
     </message>
-    <message>
-        <source>Server has been removed</source>
-        <translation>O servidor foi removido</translation>
-    </message>
-    <message>
-        <source>You have not logged in to the server</source>
-        <translation>Não iniciou sessão no servidor</translation>
-    </message>
-    <message>
-        <source>You do not have permission to access this library</source>
-        <translation>Não tem permissão para aceder a esta biblioteca</translation>
-    </message>
-    <message>
-        <source>The storage space of the library owner has been used up</source>
-        <translation>O espaço do proprietário da biblioteca está a ser utilizado por completo</translation>
-    </message>
-    <message>
-        <source>Remote service is not available</source>
-        <translation>Serviço remoto não está disponível</translation>
-    </message>
-    <message>
-        <source>Access denied to service</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Internal data corrupted</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to start upload</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to start download</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Library is damaged on server</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Conflict in merge</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Server version is too old</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Unknown error</source>
         <translation type="unfinished"/>
@@ -1767,10 +1705,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>Server error</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Bad request</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation type="unfinished"/>
@@ -1795,58 +1729,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>The storage quota has been used up</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Internal server error</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Your %1 client is too old</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to sync this library</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Files are locked by other application</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Library is deleted on server</source>
-        <translation>Biblioteca eliminada no servidor</translation>
-    </message>
-    <message>
-        <source>Error when accessing the local folder</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>initializing...</source>
         <translation>a inicializar...</translation>
     </message>
-    <message>
-        <source>Failed to index local files</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to check server information</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to create local files</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to merge local file changes</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Incorrect password. Please download again</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Internal error</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>connecting server...</source>
         <translation>a establecer ligação ao servidor...</translation>
@@ -2147,18 +2033,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>%1 Client is already running</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occurred in upload</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Error occurred in download</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Permission denied on server. Please try to resync the library</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Internal data corrupt on the client. Please try to resync the library</source>
         <translation type="unfinished"/>
@@ -2167,10 +2041,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>Do not have write permission to the library</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Do not have permission to sync the library</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>No permission to sync this folder</source>
         <translation type="unfinished"/>
@@ -2256,7 +2126,19 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Updates in read-only library will not be uploaded</source>
+        <source>Created or updated a file in a non-writable library or folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission denied on server</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Concurrent updates to file. File is saved as conflict file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>A folder that may contain not-yet-uploaded files is moved to seafile-recycle-bin folder.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -2647,6 +2529,29 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SeafileExtensionHandler</name>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to lock file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to unlock file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; is locked by %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to get lock information for file &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>SeafileLinkDialog</name>
     <message>
@@ -2665,6 +2570,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>%1 Internal Link:</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Desktop Access Link:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileRpcClient</name>
@@ -2779,6 +2688,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>Faild to fix sync status icons for Explorer</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>have some sync error</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SearchResultListView</name>
@@ -3104,17 +3017,6 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>ShibLoginDialog</name>
-    <message>
-        <source>Login with Shibboleth</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to save current account</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>SslConfirmDialog</name>
     <message>
