@@ -915,6 +915,10 @@ failed to upload.</source>
         <source>File save failed</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Index progress request error %1</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileBrowserSearchModel</name>
@@ -1087,13 +1091,6 @@ failed to upload.</source>
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>FinderSyncHost</name>
-    <message>
-        <source>Failed to get link</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>GetFileTask</name>
     <message>
@@ -1481,11 +1478,6 @@ Do you like to download your default library?</source>
 </context>
 <context>
     <name>MessagePoller</name>
-    <message>
-        <source>&quot;%1&quot; is unsynced. 
-Reason: Deleted on server</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>&quot;%1&quot; is synchronized</source>
         <translation type="unfinished"/>
@@ -1494,10 +1486,6 @@ Reason: Deleted on server</source>
         <source>Files uploaded to &quot;%1&quot;</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>File %1 conflict</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Failed to sync file %1
 File is locked by other application. This file will be updated when you close the application.</source>
@@ -1533,13 +1521,23 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>&quot;%1&quot; failed to sync. 
-Access denied to service</source>
+        <source>No permission to sync folder %1.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>&quot;%1&quot; failed to sync.
-The library owner&apos;s storage space is used up.</source>
+        <source>Updates in read-only library %1 will not be uploaded.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Concurrent updates to file. File %1 is saved as conflict file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Folder %1 is moved to seafile-recycle-bin folder since it contains not-yet uploaded files.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Folder for library %1 is removed or moved. The library is unsynced.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -1676,54 +1674,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>unknown</source>
         <translation>未知</translation>
     </message>
-    <message>
-        <source>Server has been removed</source>
-        <translation>伺服器已被刪除</translation>
-    </message>
-    <message>
-        <source>You have not logged in to the server</source>
-        <translation>您還沒有登入過此伺服器</translation>
-    </message>
-    <message>
-        <source>You do not have permission to access this library</source>
-        <translation>您沒有訪問此資料庫的權限</translation>
-    </message>
-    <message>
-        <source>The storage space of the library owner has been used up</source>
-        <translation>配額用盡了...</translation>
-    </message>
-    <message>
-        <source>Remote service is not available</source>
-        <translation>遠程服務器不可用</translation>
-    </message>
-    <message>
-        <source>Access denied to service</source>
-        <translation>請求服務時被拒絕</translation>
-    </message>
-    <message>
-        <source>Internal data corrupted</source>
-        <translation>內部數據損毀</translation>
-    </message>
-    <message>
-        <source>Failed to start upload</source>
-        <translation>無法開始上傳</translation>
-    </message>
-    <message>
-        <source>Failed to start download</source>
-        <translation>無法開始下載</translation>
-    </message>
-    <message>
-        <source>Library is damaged on server</source>
-        <translation>資料庫在伺服器上的檔案已損毀</translation>
-    </message>
-    <message>
-        <source>Conflict in merge</source>
-        <translation>omg... 合併時候發生衝突</translation>
-    </message>
-    <message>
-        <source>Server version is too old</source>
-        <translation>伺服器版本過舊</translation>
-    </message>
     <message>
         <source>Unknown error</source>
         <translation>遭遇未知錯誤</translation>
@@ -1764,10 +1714,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>Server error</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Bad request</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Not enough memory</source>
         <translation type="unfinished"/>
@@ -1792,58 +1738,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>The storage quota has been used up</source>
         <translation>空間配額已用盡</translation>
     </message>
-    <message>
-        <source>Internal server error</source>
-        <translation>內部伺服器錯誤</translation>
-    </message>
-    <message>
-        <source>Your %1 client is too old</source>
-        <translation>您%1 的客戶端版本過舊</translation>
-    </message>
-    <message>
-        <source>Failed to sync this library</source>
-        <translation>無法同步此資料庫</translation>
-    </message>
-    <message>
-        <source>Files are locked by other application</source>
-        <translation>檔案已被其他應用程式鎖住</translation>
-    </message>
-    <message>
-        <source>Library is deleted on server</source>
-        <translation>伺服器已刪除此資料庫</translation>
-    </message>
-    <message>
-        <source>Error when accessing the local folder</source>
-        <translation>在開啟本地資料夾時候遭遇錯誤</translation>
-    </message>
     <message>
         <source>initializing...</source>
         <translation>初始化中... </translation>
     </message>
-    <message>
-        <source>Failed to index local files</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to check server information</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to create local files</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Failed to merge local file changes</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Incorrect password. Please download again</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Internal error</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>connecting server...</source>
         <translation>連接伺服器中...</translation>
@@ -2144,18 +2042,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>%1 Client is already running</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Error occurred in upload</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Error occurred in download</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Permission denied on server. Please try to resync the library</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Internal data corrupt on the client. Please try to resync the library</source>
         <translation type="unfinished"/>
@@ -2165,11 +2051,103 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Do not have permission to sync the library</source>
+        <source>No permission to sync this folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>No permission to sync this folder</source>
+        <source>Removed all items from trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Removed items older than days %1 from trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Published draft</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created draft</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Renamed file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted draft</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restored file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Moved file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Updated file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Renamed folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restored folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Moved folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Renamed library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Deleted library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restored library</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Created or updated a file in a non-writable library or folder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Permission denied on server</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Concurrent updates to file. File is saved as conflict file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>A folder that may contain not-yet-uploaded files is moved to seafile-recycle-bin folder.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -2210,10 +2188,6 @@ The library owner&apos;s storage space is used up.</source>
         <source>RepoName</source>
         <translation>資料庫名稱</translation>
     </message>
-    <message>
-        <source>Description:</source>
-        <translation>描述詞：</translation>
-    </message>
     <message>
         <source>TextLabel</source>
         <translation>文本標簽：</translation>
@@ -2565,6 +2539,29 @@ The library owner&apos;s storage space is used up.</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>SeafileExtensionHandler</name>
+    <message>
+        <source>Failed to get link</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to lock file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to unlock file</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; is locked by %2</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to get lock information for file &quot;%1&quot;</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>SeafileLinkDialog</name>
     <message>
@@ -2583,6 +2580,10 @@ The library owner&apos;s storage space is used up.</source>
         <source>%1 Internal Link:</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>%1 Desktop Access Link:</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SeafileRpcClient</name>
@@ -2685,6 +2686,22 @@ The library owner&apos;s storage space is used up.</source>
         <source>Please login first</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Repair explorer extension</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Successfully fixed sync status icons for Explorer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Faild to fix sync status icons for Explorer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>have some sync error</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SearchResultListView</name>
