@@ -187,6 +187,7 @@ void FileTableViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem
             QRect status_icon_rect(status_icon_pos, QSize(kFileStatusIconSize, kFileStatusIconSize));
 
             QPixmap status_icon_pixmap = getFileStatusIcon(file_status).pixmap(status_icon_rect.size());
+            qDebug("file browser icon status is %d\n", (int)file_status);
 
             painter->save();
             painter->drawPixmap(status_icon_rect, status_icon_pixmap);
@@ -947,11 +948,14 @@ QVariant FileTableModel::data(const QModelIndex & index, int role) const
 
     if (role == Qt::DecorationRole && column == FILE_COLUMN_NAME) {
         QIcon icon;
+
+        // These are the thumnail types supported by the server (as of 2019.1)
+        static QSet<QString> image_file_types = {"gif", "png", "jpg", "jpeg", "ico"};
         if (dirent.isDir()) {
             icon = dirent.readonly
                        ? QIcon(":/images/files_v2/file_folder_readonly.png")
                        : QIcon(":/images/files_v2/file_folder.png");
-        } else if (iconPrefixFromFileName(dirent.name) == "image") {
+        } else if (image_file_types.contains(QFileInfo(dirent.name).suffix().toLower())) {
             FileBrowserDialog *dialog =
                 (FileBrowserDialog *)(QObject::parent());
             ThumbnailService *service = ThumbnailService::instance();
