@@ -144,6 +144,8 @@ SeafileTrayIcon::SeafileTrayIcon(QObject *parent)
 #if !defined(Q_OS_LINUX)
     connect(this, SIGNAL(messageClicked()),
             this, SLOT(onMessageClicked()));
+    connect(this, SIGNAL(messageClicked()),
+            this, SLOT(showSyncErrorsDialog()));
 #endif
 
     hide();
@@ -161,6 +163,8 @@ void SeafileTrayIcon::start()
 #if defined(Q_OS_MAC)
     utils::mac::set_darkmode_watcher(&darkmodeWatcher);
 #endif
+    sync_errors_dialog_ = new SyncErrorsDialog;
+    sync_errors_dialog_->updateErrors();
 }
 
 void SeafileTrayIcon::createActions()
@@ -606,6 +610,10 @@ void SeafileTrayIcon::showSettingsWindow()
     seafApplet->settingsDialog()->activateWindow();
 }
 
+void SeafileTrayIcon::slotSyncErrorUpdate() {
+    setSyncErrorStatus(true);
+}
+
 void SeafileTrayIcon::onActivated(QSystemTrayIcon::ActivationReason reason)
 {
 #if !defined(Q_OS_MAC)
@@ -653,6 +661,11 @@ void SeafileTrayIcon::refreshTrayIcon()
         return;
     }
 
+    if (haveSyncError()) {
+        setState(STATE_SERVERS_NOT_CONNECTED, tr("have some sync error"));
+        return;
+    }
+
     setState(STATE_DAEMON_UP);
 }
 
@@ -722,6 +735,8 @@ void SeafileTrayIcon::checkTrayIconMessageQueue()
 
 void SeafileTrayIcon::showSyncErrorsDialog()
 {
+    // Change icon status to daemon up when show sync errors dialog
+    setState(STATE_DAEMON_UP);
     if (sync_errors_dialog_ == nullptr) {
         sync_errors_dialog_ = new SyncErrorsDialog;
     }
@@ -730,4 +745,5 @@ void SeafileTrayIcon::showSyncErrorsDialog()
     sync_errors_dialog_->show();
     sync_errors_dialog_->raise();
     sync_errors_dialog_->activateWindow();
+    setSyncErrorStatus(false);
 }
